@@ -1,13 +1,12 @@
 """
-此模块提供了 CQHTTP API 相关的实现类。
+此模块提供了 OneBot (CQHTTP) API 相关的实现类。
 """
 
-import abc
 import asyncio
 import sys
-from typing import Callable, Dict, Any, Optional, Union, Awaitable
+from typing import Callable, Dict, Any, Optional, Set, Union, Awaitable
 
-from .api import Api
+from .api import Api, AsyncApi, SyncApi
 
 try:
     import ujson as json
@@ -16,7 +15,7 @@ except ImportError:
 
 import httpx
 from quart import websocket as event_ws
-from quart.wrappers.request import Websocket
+from quart.wrappers.websocket import Websocket
 
 from .exceptions import ActionFailed, ApiNotAvailable, HttpFailed, NetworkError
 from .utils import sync_wait
@@ -26,29 +25,17 @@ __pdoc__ = {
 }
 
 
-class AsyncApi(Api):
-    """
-    异步 API 接口类。
-
-    继承此类的具体实现类应实现异步的 `call_action` 方法。
-    """
-
-    @abc.abstractmethod
-    async def call_action(self, action: str, **params) -> Any:
-        pass
-
-
 def _handle_api_result(result: Optional[Dict[str, Any]]) -> Any:
     """
     Retrieve 'data' field from the API result object.
 
-    :param result: API result that received from CQHTTP
+    :param result: API result that received from OneBot
     :return: the 'data' field in result object
     :raise ActionFailed: the 'status' field is 'failed'
     """
     if isinstance(result, dict):
-        if result.get('status') == 'failed':
-            raise ActionFailed(retcode=result.get('retcode'))
+        if result['status'] == 'failed':
+            raise ActionFailed(result=result)
         return result.get('data')
 
 
@@ -56,12 +43,10 @@ class HttpApi(AsyncApi):
     """
     HTTP API 实现类。
 
-    实现通过 HTTP 调用 CQHTTP API。
+    实现通过 HTTP 调用 OneBot API。
     """
 
-    def __init__(self,
-                 api_root: Optional[str],
-                 access_token: Optional[str],
+    def __init__(self, api_root: Optional[str], access_token: Optional[str],
                  timeout_sec: float):
         super().__init__()
         self._api_root = api_root.rstrip('/') + '/' if api_root else None
@@ -79,7 +64,8 @@ class HttpApi(AsyncApi):
         try:
             async with httpx.AsyncClient() as client:
                 resp = await client.post(self._api_root + action,
-                                         json=params, headers=headers)
+                                         json=params,
+                                         headers=headers)
             if 200 <= resp.status_code < 300:
                 return _handle_api_result(json.loads(resp.text))
             raise HttpFailed(resp.status_code)
@@ -129,37 +115,43 @@ class WebSocketReverseApi(AsyncApi):
     """
     反向 WebSocket API 实现类。
 
-    实现通过反向 WebSocket 调用 CQHTTP API。
+    实现通过反向 WebSocket 调用 OneBot API。
     """
 
-    def __init__(self,
-                 connected_clients: Dict[str, Websocket],
+    def __init__(self, connected_api_clients: Dict[str, Websocket],
+                 connected_event_clients: Set[Websocket],
                  timeout_sec: float):
         super().__init__()
-        self._clients = connected_clients
+        self._api_clients = connected_api_clients
+        self._event_clients = connected_event_clients
         self._timeout_sec = timeout_sec
 
     async def call_action(self, action: str, **params) -> Any:
         api_ws = None
         if params.get('self_id'):
             # 明确指定
-            api_ws = self._clients.get(str(params['self_id']))
-        elif event_ws and event_ws.headers['X-Self-ID'] in self._clients:
+            api_ws = self._api_clients.get(str(params['self_id']))
+        elif event_ws and event_ws in self._event_clients:
             # 没有指定，但在事件处理函数中
-            api_ws = self._clients.get(event_ws.headers['X-Self-ID'])
-        elif len(self._clients) == 1:
+            api_ws = self._api_clients.get(event_ws.headers['X-Self-ID'])
+        elif len(self._api_clients) == 1:
             # 没有指定，不在事件处理函数中，但只有一个连接
-            api_ws = tuple(self._clients.values())[0]
+            api_ws = tuple(self._api_clients.values())[0]
 
         if not api_ws:
             raise ApiNotAvailable
 
         seq = _SequenceGenerator.next()
-        await api_ws.send(json.dumps({
-            'action': action, 'params': params, 'echo': {'seq': seq}
-        }))
-        return _handle_api_result(
-            await ResultStore.fetch(seq, self._timeout_sec))
+        await api_ws.send(
+            json.dumps({
+                'action': action,
+                'params': params,
+                'echo': {
+                    'seq': seq
+                }
+            }))
+        return _handle_api_result(await
+                                  ResultStore.fetch(seq, self._timeout_sec))
 
 
 class UnifiedApi(AsyncApi):
@@ -200,25 +192,24 @@ class UnifiedApi(AsyncApi):
         return result
 
 
-class SyncApi(Api):
+class SyncWrapperApi(SyncApi):
     """
     封装 `AsyncApi` 对象，使其可同步地调用。
     """
 
-    def __init__(self, async_api: AsyncApi, loop: asyncio.AbstractEventLoop):
+    def __init__(self, async_api: AsyncApi,
+                 loop: Optional[asyncio.AbstractEventLoop] = None):
         """
         `async_api` 参数为 `AsyncApi` 对象，`loop` 参数为用来执行 API
         调用的 event loop。
         """
         self._async_api = async_api
-        self._loop = loop
+        self._loop = loop or asyncio.get_event_loop()
 
     def call_action(self, action: str, **params) -> Any:
-        """同步地调用 CQHTTP API。"""
-        return sync_wait(
-            coro=self._async_api.call_action(action, **params),
-            loop=self._loop
-        )
+        """同步地调用 OneBot API。"""
+        return sync_wait(coro=self._async_api.call_action(action, **params),
+                         loop=self._loop)
 
 
 class LazyApi(Api):
@@ -230,6 +221,6 @@ class LazyApi(Api):
         self._api_getter = api_getter
 
     def call_action(self, action: str, **params) -> Union[Awaitable[Any], Any]:
-        """获取 `Api` 对象，并调用 CQHTTP API。"""
+        """获取 `Api` 对象，并调用 OneBot API。"""
         api = self._api_getter()
         return api.call_action(action, **params)
